@@ -1,11 +1,10 @@
 import re
 from exception import UnparseableNameException
-from names     import SUFFIX_RE, PersonName, PoliticianName, RunningMatesNames, \
+from names import SUFFIX_RE, PersonName, PoliticianName, RunningMatesNames, \
     OrganizationName
 from nicknames import NICKNAMES
 
 
-
 class BaseNameCleaver(object):
 
     def cannot_parse(self, safe, e=None):
@@ -36,12 +35,16 @@ class IndividualNameCleaver(BaseNameCleaver):
             try:
                 self.name = self.pre_process(self.name)
 
-                name, honorific, suffix, nick = self.separate_affixes(self.name)
+                if len(self.name.split()) > 2:
+                    name, honorific, suffix, nick = self.separate_affixes(self.name)
+                else:
+                    name, honorific, suffix, nick = self.name, None, None, None
 
                 if honorific and not honorific.endswith('.'):
                     honorific += '.'
 
                 name = self.reverse_last_first(name)
+                print name, nick, honorific, suffix
                 self.name = self.convert_name_to_obj(name, nick, honorific, suffix)
             except Exception, e:
                 return self.cannot_parse(safe, e)
@@ -62,9 +65,15 @@ class IndividualNameCleaver(BaseNameCleaver):
 
     def separate_affixes(self, name):
         name, honorific = self.extract_matching_portion(r'\b(?P<honorific>[dm][rs]s?[,.]?)(?=(\b|\s))+', name)
-        name, suffix = self.extract_suffix(name)
+
+        if len(name.split()) > 2:
+            name, suffix = self.extract_suffix(name)
+        else:
+            suffix = None
+
         if suffix:
             suffix = suffix.replace('.', '')
+
         name, junk = self.extract_matching_portion(r'(?P<junk_numbers>\b\d{2,}(?=(\b|\s))+)', name)
         name, nick = self.extract_matching_portion(r'("[^"]*")', name)
 
@@ -235,12 +244,12 @@ class OrganizationNameCleaver(object):
 
     @classmethod
     def name_processing_failed(cls, subject_name):
-        return not isinstance(subject_name, self.object_class)
+        return not isinstance(subject_name, cls.object_class)
 
     @classmethod
     def compare(cls, match, subject):
         """
-            Accepts two OrganizationName objects and returns an arbitrary, 
+            Accepts two OrganizationName objects and returns an arbitrary,
             numerical score based upon how well the names match.
         """
         if match.expand().lower() == subject.expand().lower():
@@ -249,9 +258,8 @@ class OrganizationNameCleaver(object):
             return 3
         # law and lobbying firms in CRP data typically list only the first two partners
         # before 'et al'
-        elif ',' in subject.expand(): # we may have a list of partners
+        elif ',' in subject.expand():  # we may have a list of partners
             if subject.crp_style_firm_name() == str(match).lower():
                 return 3
         else:
             return 2
-
