@@ -194,7 +194,7 @@ class PersonName(Name):
         if len(args):
             if self.is_an_honorific(args[-1]):
                 self.honorific = args.pop()
-            if self.is_a_suffix(args[-1]):
+            if len(args) > 2 and self.is_a_suffix(args[-1]):
                 self.suffix = args.pop()
             if self.is_a_nickname(args[-1]):
                 self.nick = args.pop()
