@@ -162,73 +162,79 @@ class TestOrganizationNameCleaver(unittest.TestCase):
 
 
 class TestIndividualNameCleaver(unittest.TestCase):
+    cleaver = IndividualNameCleaver
+
+    def cleave_to_str(self, name_input):
+        return str(self.cleaver(name_input).parse())
 
     def test_allow_names_to_have_only_last_name(self):
-        self.assertEqual('Lee', str(IndividualNameCleaver('LEE').parse()))
+        self.assertEqual('Lee', self.cleave_to_str('LEE'))
 
     def test_all_kinds_of_crazy(self):
-        self.assertEqual('Stanford Z Rothschild', str(IndividualNameCleaver('ROTHSCHILD 212, STANFORD Z MR').parse()))
+        self.assertEqual('Stanford Z Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MR'))
 
     def test_jr_and_the_like_end_up_at_the_end(self):
-        self.assertEqual('Frederick A "Tripp" Baird III', str(IndividualNameCleaver('Baird, Frederick A "Tripp" III').parse()))
+        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Frederick A "Tripp" III'))
 
     def test_nicknames_suffixes_and_honorifics(self):
-        self.assertEqual('Frederick A "Tripp" Baird III', str(IndividualNameCleaver('Baird, Frederick A "Tripp" III Mr').parse()))
-        self.assertEqual('Frederick A "Tripp" Baird III', str(IndividualNameCleaver('Baird, Mr Frederick A "Tripp" III').parse()))
+        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Frederick A "Tripp" III Mr'))
+        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Mr Frederick A "Tripp" III'))
 
     def test_throw_out_mr(self):
-        self.assertEqual('T Boone Pickens', str(IndividualNameCleaver('Mr T Boone Pickens').parse()))
-        self.assertEqual('T Boone Pickens', str(IndividualNameCleaver('Mr. T Boone Pickens').parse()))
-        self.assertEqual('T Boone Pickens', str(IndividualNameCleaver('Pickens, T Boone Mr').parse()))
-        self.assertEqual('John L Nau', str(IndividualNameCleaver(' MR JOHN L NAU,').parse()))
+        self.assertEqual('T Boone Pickens', self.cleave_to_str('Mr T Boone Pickens'))
+        self.assertEqual('T Boone Pickens', self.cleave_to_str('Mr. T Boone Pickens'))
+        self.assertEqual('T Boone Pickens', self.cleave_to_str('Pickens, T Boone Mr'))
+        self.assertEqual('John L Nau', self.cleave_to_str(' MR JOHN L NAU,'))
 
     def test_keep_the_mrs(self):
-        self.assertEqual('Mrs. T Boone Pickens', str(IndividualNameCleaver('Mrs T Boone Pickens').parse()))
-        self.assertEqual('Mrs. T Boone Pickens', str(IndividualNameCleaver('Mrs. T Boone Pickens').parse()))
-        self.assertEqual('Mrs. Stanford Z Rothschild', str(IndividualNameCleaver('ROTHSCHILD 212, STANFORD Z MRS').parse()))
+        self.assertEqual('Mrs. T Boone Pickens', self.cleave_to_str('Mrs T Boone Pickens'))
+        self.assertEqual('Mrs. T Boone Pickens', self.cleave_to_str('Mrs. T Boone Pickens'))
+        self.assertEqual('Mrs. Stanford Z Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MRS'))
 
     def test_mrs_walton(self):
-        self.assertEqual('Mrs. Jim Walton', str(IndividualNameCleaver('WALTON, JIM MRS').parse()))
+        self.assertEqual('Mrs. Jim Walton', self.cleave_to_str('WALTON, JIM MRS'))
 
     def test_capitalize_roman_numeral_suffixes(self):
-        self.assertEqual('Ken Cuccinelli II', str(IndividualNameCleaver('KEN CUCCINELLI II').parse()))
-        self.assertEqual('Ken Cuccinelli II', str(IndividualNameCleaver('CUCCINELLI II, KEN').parse()))
-        self.assertEqual('Ken Cuccinelli IV', str(IndividualNameCleaver('CUCCINELLI IV, KEN').parse()))
-        self.assertEqual('Ken Cuccinelli IX', str(IndividualNameCleaver('CUCCINELLI IX, KEN').parse()))
-        self.assertEqual('Ken T Cuccinelli II', str(PoliticianNameCleaver('CUCCINELLI II, KEN T').parse()))
-        self.assertEqual('Ken T Cuccinelli II', str(PoliticianNameCleaver('CUCCINELLI, KEN T II').parse()))
+        self.assertEqual('Ken Cuccinelli II', self.cleave_to_str('KEN CUCCINELLI II'))
+        self.assertEqual('Ken Cuccinelli II', self.cleave_to_str('CUCCINELLI II, KEN'))
+        self.assertEqual('Ken Cuccinelli IV', self.cleave_to_str('CUCCINELLI IV, KEN'))
+        self.assertEqual('Ken Cuccinelli IX', self.cleave_to_str('CUCCINELLI IX, KEN'))
 
     def test_capitalize_scottish_last_names(self):
-        self.assertEqual('Ronald McDonald', str(IndividualNameCleaver('RONALD MCDONALD').parse()))
-        self.assertEqual('Old MacDonald', str(IndividualNameCleaver('OLD MACDONALD').parse()))
+        self.assertEqual('Ronald McDonald', self.cleave_to_str('RONALD MCDONALD'))
+        self.assertEqual('Old MacDonald', self.cleave_to_str('OLD MACDONALD'))
 
     def test_capitalizes_and_punctuates_initials(self):
-        self.assertEqual('B.L. Schwartz', str(IndividualNameCleaver('SCHWARTZ, BL').parse()))
+        self.assertEqual('B.L. Schwartz', self.cleave_to_str('SCHWARTZ, BL'))
 
     def test_capitalizes_initials_but_not_honorifics(self):
-        self.assertEqual('John Koza', str(IndividualNameCleaver('KOZA, DR JOHN').parse()))
+        self.assertEqual('John Koza', self.cleave_to_str('KOZA, DR JOHN'))
 
     def test_doesnt_overzealously_detect_doctors(self):
-        self.assertEqual('Drew Maloney', str(IndividualNameCleaver('Maloney, Drew').parse()))
+        self.assertEqual('Drew Maloney', self.cleave_to_str('Maloney, Drew'))
 
     def test_unfazed_by_weird_cop_cont_parenthetical_phrases(self):
-        self.assertEqual('Jacqueline A Schmitz', str(IndividualNameCleaver('SCHMITZ (COP CONT ), JACQUELINE A').parse()))
-        self.assertEqual('Hannah Mellman', str(IndividualNameCleaver('MELLMAN (CONT\'D), HANNAH (CONT\'D)').parse()))
-        self.assertEqual('Tod Preston', str(IndividualNameCleaver('PRESTON (C O P CONT\'D ), TOD').parse()))
+        self.assertEqual('Jacqueline A Schmitz', self.cleave_to_str('SCHMITZ (COP CONT ), JACQUELINE A'))
+        self.assertEqual('Hannah Mellman', self.cleave_to_str('MELLMAN (CONT\'D), HANNAH (CONT\'D)'))
+        self.assertEqual('Tod Preston', self.cleave_to_str('PRESTON (C O P CONT\'D ), TOD'))
 
     def test_mr_and_mrs(self):
-        self.assertEqual('Kenneth L Lay', str(IndividualNameCleaver('LAY, KENNETH L MR & MRS').parse()))
+        self.assertEqual('Kenneth L Lay', self.cleave_to_str('LAY, KENNETH L MR & MRS'))
 
     def test_primary_name_parts(self):
-        self.assertEqual(['Robert', 'Geoff', 'Smith'], IndividualNameCleaver('Smith, Robert Geoff').parse().primary_name_parts(include_middle=True))
-        self.assertEqual(['Robert', 'Smith'], IndividualNameCleaver('Smith, Robert Geoff').parse().primary_name_parts())
+        self.assertEqual(['Robert', 'Geoff', 'Smith'], self.cleaver('Smith, Robert Geoff').parse().primary_name_parts(include_middle=True))
+        self.assertEqual(['Robert', 'Smith'], self.cleaver('Smith, Robert Geoff').parse().primary_name_parts())
 
     def test_initialed_first_name(self):
-        self.assertEqual('C. Richard Bonebrake', str(IndividualNameCleaver('C. RICHARD BONEBRAKE').parse()))
+        self.assertEqual('C. Richard Bonebrake', self.cleave_to_str('C. RICHARD BONEBRAKE'))
 
     def test_md(self):
-        self.assertEqual('C. Richard Bonebrake MD', str(IndividualNameCleaver('C. RICHARD BONEBRAKE, M.D.').parse()))
-        self.assertEqual('John W. Noble Jr. MD', str(IndividualNameCleaver('NOBLE JR., JOHN W. MD').parse()))
+        self.assertEqual('C. Richard Bonebrake MD', self.cleave_to_str('C. RICHARD BONEBRAKE, M.D.'))
+        self.assertEqual('John W. Noble Jr. MD', self.cleave_to_str('NOBLE JR., JOHN W. MD'))
+
+    def test_two_part_names_skip_suffix_check(self):
+        self.assertEqual('Vi Simpson', self.cleave_to_str('SIMPSON, VI'))
+        self.assertEqual('JR Reskovac', self.cleave_to_str('RESKOVAC, JR'))
 
 
 class TestCapitalization(unittest.TestCase):
